<template>
    <div custom-class="bbsl-location-dialog" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <el-dialog :title="title" :visible.sync="dialogVisible" width="50%" :close-on-click-modal="false"
            :before-close="handleClose" :class="[reqLoading ? 'dialog-box' : '']">
            <div v-loading="reqLoading" element-loading-text="加载中..." element-loading-spinner="el-icon-loading"
                element-loading-background="rgba(255, 255, 255, 1)">
                <el-form ref="form" :model="formData" label-width="80px" :rules="rules">
                    <el-row>
                        <el-col :span="24">
                            <el-form-item label="资料名称" prop="profileName">
                                <el-input v-model="formData.profileName"></el-input>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="文件类型" prop="profileType" v-if="formData.profileType != '7'">
                                <el-select clearable v-model="formData.profileType"
                                    :disabled="formData.profileType == 7" placeholder="请选择文件类型" style="width: 100%">
                                    <el-option v-for="item in fileTypeOptions" :key="item.id" :label="item.name"
                                        :value="item.value">
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12" v-if="formData.profileType == '2'">
                            <el-form-item label="获奖分类" prop="profileInnovationClassify">
                                <dict-select dictCode="hjfl" v-model="formData.profileInnovationClassify"
                                    :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择获奖分类" />
                            </el-form-item>
                        </el-col>
                        <el-col :span="12" v-if="formData.profileType == '5'">
                            <el-form-item label="模块类别" prop="profileModuleClassify">
                                <dict-select dictCode="mklb" v-model="formData.profileModuleClassify"
                                    :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择模块类别" />
                            </el-form-item>
                        </el-col>
                        <el-col :span="12" v-if="formData.profileType == '7'">
                            <el-form-item label="资料分类" prop="profileClassify">
                                <dict-select dictCode="zxxz_zllx" v-model="formData.profileClassify"
                                    :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择资料分类" />
                            </el-form-item>
                        </el-col>
                        <el-col :span="12" v-if="formData.profileClassify == '3' || formData.profileClassify == '4'">
                            <el-form-item label="文件年份" prop="profileYear">
                                <el-date-picker style="width: 100%" v-model="formData.profileYear" value-format="yyyy" type="year" placeholder="选择文件年份">
                                </el-date-picker>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row>
                        <el-form-item label="附件上传" prop="files">
                            <el-button class="updload_btn" size="small" type="primary" @click="openUploade">
                                点击上传
                            </el-button>
                            <FileList :fileList="formData.files" :isDelete="true" @changeFileList="changeFileList">
                            </FileList>
                            <span style="color:#f56c6c" v-if="formData.classified == '1'">
                                * 文件涉密，已通过内网上传。
                            </span>
                        </el-form-item>
                    </el-row>
                </el-form>
            </div>
            <span slot="footer" class="dialog-footer" :style="reqLoading ? 'position: relative;z-index: -1;' : ''">
                <template v-if="formData.status == 1">
                    <el-button type="primary" @click="handleSave(1, 'update')">保存</el-button>
                </template>
                <template v-else>
                    <el-button type="primary" @click="handleSave(1)">保存并发布</el-button>
                    <el-button @click="handleSave(0)">保存为草稿</el-button>
                </template>
                <el-button @click="handleClose">取 消</el-button>
            </span>
        </el-dialog>

        <UploadFile ref="uploadFile" @setFileList="setFileList" @setAipher="setAipher"></UploadFile>
    </div>
</template>

<script>
import UploadFile from '@/components/uploadFile/index.vue'
import FileList from '@/components/uploadFile/FileList.vue'
import RejectInfoDialog from '@/components/dialog/RejectInfoDialog.vue'
import apiList from '@/api/WorkItems/fileLibrary.js'
import utils from '@/utils.js'
export default {
    name: 'fileLibraryDialog',
    components: {
        UploadFile,
        FileList,
        RejectInfoDialog
    },
    data() {
        var checkfiles = (rule, value, callback) => {
            if ((!this.formData.files || !this.formData.files.length) && this.formData.classified != '1') {
                return callback(new Error('请上传相关附件'))
            } else {
                callback()
            }
        }
        return {
            markLoading: false,
            reqLoading: false,
            dialogVisible: false,
            title: '新增',
            formData: {},
            rules: {
                profileName: [
                    { required: true, message: '请输入资料名称', trigger: 'change' },
                ],
                profileType: [
                    { required: true, message: '请选择资料类型', trigger: 'change' },
                ],
                profileClassify: [
                    { required: true, message: '请选择资料分类', trigger: 'change' },
                ],
                profileInnovationClassify: [
                    { required: true, message: '请选择获奖分类', trigger: 'change' },
                ],
                profileModuleClassify: [
                    { required: true, message: '请选择模块类别', trigger: 'change' },
                ],
                profileYear: [
                    { required: true, message: '请选择文件年份', trigger: 'change' },
                ],
                files: [
                    { required: true, validator: checkfiles, trigger: 'change' },
                ]
            },
            prams: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0
                }
            },
            dialogType: '',
            fileTypeOptions: []
        }
    },
    created() {
    },
    methods: {
        open(type, item) {
            this.fileTypeOptions = utils.getDictItemsFromCache('sjk_wjlx')
            this.dialogType = type
            if (item) {
                this.getDetailsById(item.id)
            } else {
                if (type === 'group') {
                    this.formData.profileType = '7'
                    this.formData.groupCode = sessionStorage.getItem('currentRoleCode')
                } else {
                    this.fileTypeOptions = this.fileTypeOptions.slice(0, -1)
                }
            }
            this.dialogVisible = true
        },
        handleClose() {
            this.formData = {}
            this.$refs.form.resetFields()
            this.dialogVisible = false
        },
        openUploade() {
            this.$refs.uploadFile.open('reformFile')
        },
        setFileList(file) {
            file.id = file.response.fileId
            this.formData.files
                ? this.formData.files.push(file)
                : this.$set(this.formData, 'files', [file])
            this.formData.classified = ''
            this.setProfileName()
        },
        setAipher() {
            this.$set(this.formData, 'classified', '1')
        },
        changeFileList(arr) {
            this.formData.files = arr
            this.setProfileName()
        },
        setProfileName() {
            if (this.formData.files && this.formData.files.length) {
                let profileName = this.formData.files[0].name.split('.')[0]
                // this.formData.profileName = profileName
                this.$set(this.formData, 'profileName', profileName)
            } else {
                // this.formData.profileName = ''
                this.$set(this.formData, 'profileName', '')
            }
        },
        // 保存
        handleSave(status, type) {
            this.$refs.form.validate(valid => {
                if (valid) {
                    let data = JSON.parse(JSON.stringify(this.formData))
                    data.status = status
                    let msg = type === 'update' ? '修改并保存' : status ? '保存并发布' : '保存为草稿'
                    this.$confirm(`确认${msg}吗？`, '提示', {
                        confirmButtonText: '确认',
                        cancelButtonText: '关闭',
                        type: 'success'
                    }).then(() => {
                        this.markLoading = true
                        if (data.profileType != '2') {
                            data.profileInnovationClassify = ''
                        }
                        if (data.profileType != '5') {
                            data.profileModuleClassify = ''
                        }
                        if (data.profileClassify == '3' && data.profileClassify == '4') {
                            data.profileYear = ''
                        }
                        apiList.saveOrUpdateFile(data, res => {
                            if (res.state) {
                                this.$message.success(`${msg}成功`)
                                this.handleClose()
                                this.$emit('refreshData')
                            }
                            this.markLoading = false
                        })
                    })

                }
            })
        },
        // 根据id查询详细信息
        getDetailsById(id) {
            this.reqLoading = true
            apiList.getDetailsById(id, res => {
                if (res) {
                    this.formData = res
                    this.formData.profileYear = res.profileYear ? res.profileYear + '' : ''
                    this.reqLoading = false
                }
            })
        },

    },
}
</script>

<style lang="scss" scoped>
/deep/.file-item {
    padding: 0 5px;

    .file_name {
        height: auto;
        font-size: 13PX !important;
    }
}
</style>
